[−][src]Crate bumpy_vector
BumpyVector
Provides a vector-like object where elements can be larger than one "space". We use this primarily to represent objects in a file that are potentially made up of many bytes.
TODO
- Test what happens with zero-sized entries
Structs
| BumpyEntry | Represents a single entry. |
| BumpyVector | Represents an instance of a Bumpy Vector |